@@ -1,38 +1,45 @@
-import os
 import sys
 import logging
 import posixpath as url_path
 
-import Lifetime
 import transaction
-from Testing.ZopeTestCase import utils
+
 from Products.PloneTestCase.PloneTestCase import FunctionalTestCase, default_user, default_password
 from Products.PloneTestCase.layer import PloneSite as PloneLayer
 
 import windmill
+
 from windmill.bin.admin_lib import configure_global_settings, setup, teardown
 from windmill.authoring.unit import WindmillUnitTestCase
 from windmill.authoring import WindmillTestClient
 
+from niteoweb.windmill.zserver import ZServerLayer
 
 log = logging.getLogger(__name__)
 
-class WindmillLayer:
+class WindmillLayer(ZServerLayer):
+    """Layer for running windmill. This depends on the ZServer layer, which
+    means that it will start up a ZServer instance on a random port.
+    See zserver.py for details.
+    """
+    
     site = 'plone'
+    
     windmill_settings = {
         'START_FIREFOX': True,
     }
+    
     test_url = "http://%(host)s:%(port)s/index_html"
 
     @classmethod
     def setUp(cls):
+        
         # Start the Zope server with one thread
-        host, port = utils.startZServer(1)
-        site = cls.site
+        host, port = cls.host, cls.port
         cls.test_url = cls.test_url % locals()
         log.debug('Starting ZServer on: %s' % cls.test_url)
 
-        # windmill
+        # Configure windmill
         windmill.stdout, windmill.stdin = sys.stdout, sys.stdin
         configure_global_settings()
         windmill.settings['TEST_URL'] = cls.test_url
@@ -40,7 +47,7 @@ class WindmillLayer:
         cls.windmill_shell_objects = setup()
         log.debug('Starting Windmill with settings: %r' % windmill.settings)
 
-        # configure client
+        # Configure client
         cls.wm = WindmillTestClient(__name__)
         def open_site(*a, **kw):
             """little hack to always open an url with name of plone site"""
@@ -53,14 +60,20 @@ class WindmillLayer:
     @classmethod
     def tearDown(cls):
         teardown(cls.windmill_shell_objects)
-        Lifetime.shutdown(0, fast=1)
 
 
 class WindmillPloneLayer(PloneLayer, WindmillLayer):
-    pass
+    """Convenience layer which mixes PloneLayer from PloneTestCase in with
+    WindMillLayer. Use this layer to execute a windmill test against a Plone
+    site configured using the normal PloneTestCase setup.
+    """
 
 
 class WindmillTestCase(FunctionalTestCase):
+    """Convenient test case which makes a Windmill controller availalbe on
+    self.wm and adds some convenience methods.
+    """
+    
     layer = WindmillPloneLayer
 
     @property
